@@ -1,25 +1,41 @@
 package main
 
 import (
+	"errors"
 	"log"
 	"os"
 
 	flag "github.com/spf13/pflag"
+
+	"github.com/maxmind/geoipupdate/v7/internal/vars"
 )
 
 // Args are command line arguments.
 type Args struct {
 	ConfigFile        string
 	DatabaseDirectory string
-	StackTrace        bool
 	Verbose           bool
+	Output            bool
+	Parallelism       int
 }
 
 func getArgs() *Args {
+	confFileDefault := vars.DefaultConfigFile
+	// Set the default config file only if it exists.
+	// Otherwise, geoipupdate requires the user to specify the config file
+	// even if all the other arguments are set via the environment variables.
+	if _, err := os.Stat(confFileDefault); errors.Is(err, os.ErrNotExist) {
+		confFileDefault = ""
+	}
+
+	if value, ok := os.LookupEnv("GEOIPUPDATE_CONF_FILE"); ok {
+		confFileDefault = value
+	}
+
 	configFile := flag.StringP(
 		"config-file",
 		"f",
-		defaultConfigFile,
+		confFileDefault,
 		"Configuration file",
 	)
 	databaseDirectory := flag.StringP(
@@ -29,9 +45,10 @@ func getArgs() *Args {
 		"Store databases in this directory (uses config if not specified)",
 	)
 	help := flag.BoolP("help", "h", false, "Display help and exit")
-	stackTrace := flag.Bool("stack-trace", false, "Show a stack trace along with any error message.")
 	verbose := flag.BoolP("verbose", "v", false, "Use verbose output")
+	output := flag.BoolP("output", "o", false, "Output download/update results in JSON format")
 	displayVersion := flag.BoolP("version", "V", false, "Display the version and exit")
+	parallelism := flag.Int("parallelism", 0, "Set the number of parallel database downloads")
 
 	flag.Parse()
 
@@ -44,16 +61,17 @@ func getArgs() *Args {
 		os.Exit(0)
 	}
 
-	if *configFile == "" {
-		log.Printf("You must provide a configuration file.")
+	if *parallelism < 0 {
+		log.Printf("Parallelism must be a positive number")
 		printUsage()
 	}
 
 	return &Args{
 		ConfigFile:        *configFile,
 		DatabaseDirectory: *databaseDirectory,
-		StackTrace:        *stackTrace,
 		Verbose:           *verbose,
+		Output:            *output,
+		Parallelism:       *parallelism,
 	}
 }
 
